Initiators
==========

.. automodule:: stonesoup.initiator
    :no-members:

.. automodule:: stonesoup.initiator.base
    :show-inheritance:

.. automodule:: stonesoup.initiator.simple
    :show-inheritance:


